==> yass-1.09.tar.gz: yass-1.09/global_var.h <==
/*
 *  YASS 1.09
 *  Copyright (C) 2004,2005
 *  YASS Team
 *  Laurent Noe, Gregory Kucherov, Mikhail Roytberg, Christophe Valmir, Steven Corroy
 *  yass@loria.fr
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software contains code derived from the GNU libavl library.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef  __GLOBAl_VAR_H_
#define  __GLOBAl_VAR_H_
#include <stdio.h>
#include "util.h"
#include "tuple.h"
#ifdef  BIPROC
#ifdef WIN32
#include <windows.h>
#else
#include <pthread.h>
#endif
#endif



/********************
 * GLOBALVARIABLES  *
 ********************/


/* [1]  MODIFIED WHEN STARTING PROGRAM 
 *========================================*/

/* parameters and flags */
#define MAX_SEED 32
extern char *gp_motifs[MAX_SEED];
extern int gp_seeds_span[MAX_SEED];
extern int gp_seeds_bitweight[MAX_SEED];
extern int gp_seeds_span_min;
extern int gp_seeds_span_max;
extern int gp_nb_seeds;
extern int *gp_automata;

extern int gp_minimum_score_seeds;
extern int gp_minscore;
extern int gp_mutations_percent;
extern double gp_mutations;
extern int gp_indels_percent;
extern double gp_indels;
extern int gp_alpha_percent;
extern double gp_alpha;

extern double gp_entropy_min;
extern double gp_expectation_value;

extern int gp_reverse;
extern int gp_display;
extern int gp_nbmaxlines;
extern int gp_distdiag;
extern int gp_t;

/* statisticals parameters */

extern int gp_rho_stat;
extern int gp_delta_stat;


/* post-processing */
extern int gp_win_min;
extern int gp_win_max;
extern int gp_win_mul;

/* files number et filenames */
extern int gp_nbfiles;
extern char gp_files[2][256];
extern int gp_selection_fasta;


/* cost */
extern int SUBMATRIXTABLE[4][4];
extern int INDELSTABLE[4][2];
extern int gp_cost_gap_opened;
extern int gp_cost_gap_continued;
extern int gp_cost_match;
extern int gp_cost_mismatch;
extern int gp_cost_mismatch;
extern int gp_cost_transition;
extern int gp_cost_other;
extern int gp_substitution_matrix[16][16];
extern int gp_cost_max_substitution_matrix;
extern double gp_k_blast;
extern double gp_lambda_blast;
extern int gp_xdrop;

/* data tables and their sizes  */
extern char *gp_query;
extern char *gp_text;
extern int gp_querysize;
extern int gp_textsize;
extern int gp_querysize_chunk;


/* [2]   MODIFIED WHEN RUNNING ...
 *================================*/
extern FILE *gv_outstream;
extern int gv_reverse_repeat;	/* flag to register all currently found repeats as "reversed ones"  */
extern tuplelist *gv_last_tl;	/* last tuple list added by the "assemble" algorithm */


extern MA *gv_first_MA;		/* MA in the current list */
extern MA *gv_last_MA;
extern int gv_i_current;	/* used by "assemble" and read by "align" */


/* statistical variables */

/* statistics on proccessing step */
extern int nb_seeds;
extern int nb_chains_built;
extern int nb_chains_tested;
extern int nb_ma;

/* statistics on post processing step */
extern int nb_postprocessed_grouping_tests;
extern int nb_postprocessed_grouping_links;
extern int nb_postprocessed_ma;


extern int time_spent;		/* full time spent (seconds) */
extern double last_clock;	/* last time measured */
extern double clock_align;	/* time spent to alignement (cycles of 1/1000000 s) */
extern double clock_chain;	/* time spent to chain      (cycles of 1/1000000 s) */
extern double clock_post;

extern unsigned int gp_nb_letter[2][4];	/* ['A','T','G','C'] */
extern char lookup[16];

/*Size of hash table*/
extern int gp_hash_size;
extern int gp_hash_element;

#ifdef GORE_ALLOC_TUPLE
extern tuple *tupler;
extern int i_tuple;
#endif
#ifdef GORE_ALLOC_TUPLELIST
extern tuplelist *tuplelister;
extern int i_tuplelist;
#endif

typedef struct _FEATURE_ASSEMBLE {
  char *chunk_query;
  int  nbchunks_query;
  int  querysize_chunk;

  char **chunkname_text;
  int  nbchunks_text;
  int  *chunksize_text;
  int  *chunkstrt_text;
  


  int  reverse;
  int left_correction;

  tuplelist *tuple_lists;
  tuplelist *last_tl;

  MA *first_MA;
  MA *last_MA;

  int i_current;
#ifdef  BIPROC
#ifdef WIN32
  HANDLE    thread;
#else
  pthread_t thread;
#endif
#endif

  /* Statistique */
  double clock_chain;
  double clock_align;
  double clock_post;
  int    nb_seeds;
  int    nb_chains_tested;
  int    nb_chains_built;
  int    nb_postprocessed_grouping_tests;
  int    nb_postprocessed_ma;
  int    nb_postprocessed_grouping_links;

  /* buffer prydyn*/
  int *buffer01;

  /* Variable for display */
  int last_point;

} Feature_assemble; 



#endif

==> yass-1.10.tar.gz: yass-1.10/global_var.h <==
/*
 *  YASS 1.10
 *  Copyright (C) 2004,2005
 *  YASS Team
 *  Laurent Noe, Gregory Kucherov, Mikhail Roytberg, 
 *  Christophe Valmir, Steven Corroy
 *
 *  noe|<A>|lifl.fr
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software contains code derived from the GNU libavl library.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef  __GLOBAL_VAR_H_
#define  __GLOBAL_VAR_H_
#include "util.h"
#include "tuple.h"




/********************
 * GLOBALVARIABLES  *
 ********************/


/* [1]  MODIFIED WHEN STARTING PROGRAM 
 *========================================*/

/* parameters and flags */
extern char *gp_motifs[MAX_SEED];
extern int gp_seeds_span[MAX_SEED];
extern int gp_seeds_bitweight[MAX_SEED];
extern int gp_seeds_span_min;
extern int gp_seeds_span_max;
extern int gp_nb_seeds;
extern int *gp_automata;

extern int gp_minimum_score_seeds;
extern int gp_minscore;
extern int gp_mutations_percent;
extern double gp_mutations;
extern int gp_indels_percent;
extern double gp_indels;
extern int gp_alpha_percent;
extern double gp_alpha;

extern double gp_entropy_min;
extern double gp_expectation_value;

extern int gp_reverse;
extern int gp_display;
extern int gp_nbmaxlines;
extern int gp_distdiag;
extern double gp_t;

/* statisticals parameters */

extern int gp_rho_stat;
extern int gp_delta_stat;


/* post-processing */
extern int gp_win_min;
extern int gp_win_max;
extern double gp_win_mul;

/* files number et filenames */
extern int gp_nbfiles;
extern char gp_files[2][256];
extern int gp_selection_fasta;


/* cost */
extern int SUBMATRIXTABLE[4][4];
extern int INDELSTABLE[4][2];
extern int gp_cost_gap_opened;
extern int gp_cost_gap_continued;
extern int gp_costs[4];
extern int gp_substitution_matrix[16][16];
extern int gp_cost_max_substitution_matrix;
extern int gp_matrix;
extern double gp_k_blast;
extern double gp_lambda_blast;
extern int gp_xdrop;

/* data tables and their sizes  */
extern char *gp_query;
extern int gp_querysize;

extern char *gp_query_chunk;
extern char *gp_queryrev_chunk;
extern int gp_querysize_chunk;

extern char *gp_text;
extern int gp_textsize;

/* first file chunks */
extern int     gp_nbchunks_query;
extern char ** gp_chunkname_query;
extern int   * gp_chunksize_query;
extern int   * gp_chunkstrt_query;

/* second file chunks */
extern int     gp_nbchunks_text;
extern char ** gp_chunkname_text;
extern int   * gp_chunksize_text;
extern int   * gp_chunkstrt_text;
      


/* statistical variables */
extern int gp_nb_letters[2][4];	/* ['A','T','G','C'] */
extern char lookup[16];
extern char backcode[16];

/*Size of hash table*/
extern int gp_hash_size;
extern int gp_hash_element;

#ifdef MEM_ALLOCATED
extern unsigned long gv_mem_allocated;
extern unsigned long gp_max_mem_allocated;
#endif

 
/* [2]   MODIFIED WHEN RUNNING ...
 *================================*/
extern FILE *gv_outstream;

extern MA   *gv_first_MA; /* MA in the current list */

extern int   gv_thread_result;

extern int  *gv_delta_shift;

extern int gv_nb_mutations_per_codon1[3];
extern int gv_nb_mutations_per_codon2[3];
extern int gv_nb_transitions_transversions_indels[3];
extern int gv_nb_triplet_count1[64];
extern int gv_nb_triplet_count2[64];
extern int gv_nb_non_mutated_triplet_count[64];



/* statistics on time spent */
#ifdef STATS
extern int gv_time_spent;
extern double last_clock;	/* last time measured */
#endif

#endif
